@@ -13,22 +13,27 @@ QwtPlotCurve
    :members:
 """
 
-from .text import QwtText
-from .plot import QwtPlot, QwtPlotItem, QwtPlotItem_PrivateData
-from ._math import qwtSqr
-from .graphic import QwtGraphic
-from .plot_series import (
+from qwt.text import QwtText
+from qwt.plot import QwtPlot, QwtPlotItem, QwtPlotItem_PrivateData
+from qwt._math import qwtSqr
+from qwt.graphic import QwtGraphic
+from qwt.plot_series import (
     QwtPlotSeriesItem,
     QwtSeriesStore,
     QwtSeriesData,
     QwtPointArrayData,
 )
-from .symbol import QwtSymbol
-from .plot_directpainter import QwtPlotDirectPainter
-from .qthelpers import qcolor_from_str
+from qwt.symbol import QwtSymbol
+from qwt.plot_directpainter import QwtPlotDirectPainter
+from qwt.qthelpers import qcolor_from_str
 
-from .qt.QtGui import QPen, QBrush, QPainter, QPolygonF, QColor
-from .qt.QtCore import QSize, Qt, QRectF, QPointF
+from qtpy import PYSIDE2
+from qtpy.QtGui import QPen, QBrush, QPainter, QPolygonF, QColor
+from qtpy.QtCore import QSize, Qt, QRectF, QPointF
+
+if PYSIDE2:
+    import shiboken2
+    import ctypes
 
 import numpy as np
 
@@ -55,20 +60,46 @@ def qwtVerifyRange(size, i1, i2):
     return i2 - i1 + 1
 
 
+def array2d_to_qpolygonf(xdata, ydata):
+    """
+    Utility function to convert two 1D-NumPy arrays representing curve data
+    (X-axis, Y-axis data) into a single polyline (QtGui.PolygonF object).
+    This feature is compatible with PyQt4, PyQt5 and PySide2 (requires QtPy).
+
+    License/copyright: MIT License © Pierre Raybaut 2020.
+
+    :param numpy.ndarray xdata: 1D-NumPy array (numpy.float64)
+    :param numpy.ndarray ydata: 1D-NumPy array (numpy.float64)
+    :return: Polyline
+    :rtype: QtGui.QPolygonF
+    """
+    dtype = np.float64
+    if not (
+        xdata.size == ydata.size == xdata.shape[0] == ydata.shape[0]
+        and xdata.dtype == ydata.dtype == dtype
+    ):
+        raise ValueError("Arguments must be 1D, float64 NumPy arrays with same size")
+    size = xdata.size
+    polyline = QPolygonF(size)
+    if PYSIDE2:  # PySide2 (obviously...)
+        address = shiboken2.getCppPointer(polyline.data())[0]
+        buffer = (ctypes.c_double * 2 * size).from_address(address)
+    else:  # PyQt4, PyQt5
+        buffer = polyline.data()
+        buffer.setsize(2 * size * np.finfo(dtype).dtype.itemsize)
+    memory = np.frombuffer(buffer, dtype)
+    memory[: (size - 1) * 2 + 1 : 2] = xdata
+    memory[1 : (size - 1) * 2 + 2 : 2] = ydata
+    return polyline
+
+
 def series_to_polyline(xMap, yMap, series, from_, to):
     """
     Convert series data to QPolygon(F) polyline
     """
-    polyline = QPolygonF(to - from_ + 1)
-    pointer = polyline.data()
-    dtype, tinfo = np.float, np.finfo  # integers: = np.int, np.iinfo
-    pointer.setsize(2 * polyline.size() * tinfo(dtype).dtype.itemsize)
-    memory = np.frombuffer(pointer, dtype)
-    memory[: (to - from_) * 2 + 1 : 2] = xMap.transform(series.xData()[from_ : to + 1])
-    memory[1 : (to - from_) * 2 + 2 : 2] = yMap.transform(
-        series.yData()[from_ : to + 1]
-    )
-    return polyline
+    xdata = xMap.transform(series.xData()[from_ : to + 1])
+    ydata = yMap.transform(series.yData()[from_ : to + 1])
+    return array2d_to_qpolygonf(xdata, ydata)
 
 
 class QwtPlotCurve_PrivateData(QwtPlotItem_PrivateData):
@@ -89,79 +120,79 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
 
     A curve is the representation of a series of points in the x-y plane.
     It supports different display styles and symbols.
-    
+
     .. seealso::
-    
-        :py:class:`qwt.symbol.QwtSymbol()`, 
+
+        :py:class:`qwt.symbol.QwtSymbol()`,
         :py:class:`qwt.scale_map.QwtScaleMap()`
-        
+
     Curve styles:
-    
+
       * `QwtPlotCurve.NoCurve`:
-        
+
         Don't draw a curve. Note: This doesn't affect the symbols.
-            
+
       * `QwtPlotCurve.Lines`:
 
         Connect the points with straight lines.
 
       * `QwtPlotCurve.Sticks`:
-        
-        Draw vertical or horizontal sticks ( depending on the 
+
+        Draw vertical or horizontal sticks ( depending on the
         orientation() ) from a baseline which is defined by setBaseline().
 
       * `QwtPlotCurve.Steps`:
-        
+
         Connect the points with a step function. The step function
         is drawn from the left to the right or vice versa,
         depending on the QwtPlotCurve::Inverted attribute.
 
       * `QwtPlotCurve.Dots`:
-        
+
         Draw dots at the locations of the data points. Note:
         This is different from a dotted line (see setPen()), and faster
-        as a curve in QwtPlotCurve::NoStyle style and a symbol 
+        as a curve in QwtPlotCurve::NoStyle style and a symbol
         painting a point.
 
       * `QwtPlotCurve.UserCurve`:
-        
+
         Styles >= QwtPlotCurve.UserCurve are reserved for derived
         classes of QwtPlotCurve that overload drawCurve() with
         additional application specific curve types.
-    
+
     Curve attributes:
-    
+
       * `QwtPlotCurve.Inverted`:
-        
-        For `QwtPlotCurve.Steps` only. 
+
+        For `QwtPlotCurve.Steps` only.
         Draws a step function from the right to the left.
-    
+
     Legend attributes:
-    
+
       * `QwtPlotCurve.LegendNoAttribute`:
-        
-        `QwtPlotCurve` tries to find a color representing the curve 
+
+        `QwtPlotCurve` tries to find a color representing the curve
         and paints a rectangle with it.
 
       * `QwtPlotCurve.LegendShowLine`:
-        
-        If the style() is not `QwtPlotCurve.NoCurve` a line 
+
+        If the style() is not `QwtPlotCurve.NoCurve` a line
         is painted with the curve pen().
 
       * `QwtPlotCurve.LegendShowSymbol`:
-        
+
         If the curve has a valid symbol it is painted.
 
       * `QwtPlotCurve.LegendShowBrush`:
-        
+
         If the curve has a brush a rectangle filled with the
         curve brush() is painted.
 
-            
+
     .. py:class:: QwtPlotCurve([title=None])
-    
+
         Constructor
-        
+
         :param title: Curve title
         :type title: qwt.text.QwtText or str or None
     """
@@ -211,7 +242,7 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     ):
         """
         Create and setup a new `QwtPlotCurve` object (convenience function).
-        
+
         :param xdata: List/array of x values
         :param ydata: List/array of y values
         :param title: Curve title
@@ -240,7 +271,7 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
         :param bool finite: if True, keep only finite array elements (remove all infinity and not a number values), otherwise do not filter array elements
 
         .. seealso::
-        
+
             :py:meth:`setData()`, :py:meth:`setPen()`, :py:meth:`attach()`
         """
         item = cls(title)
@@ -283,19 +314,19 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def setLegendAttribute(self, attribute, on=True):
         """
         Specify an attribute how to draw the legend icon
-        
+
         Legend attributes:
-        
+
             * `QwtPlotCurve.LegendNoAttribute`
             * `QwtPlotCurve.LegendShowLine`
             * `QwtPlotCurve.LegendShowSymbol`
             * `QwtPlotCurve.LegendShowBrush`
-            
+
         :param int attribute: Legend attribute
         :param bool on: On/Off
-        
+
         .. seealso::
-        
+
             :py:meth:`testLegendAttribute()`, :py:meth:`legendIcon()`
         """
         if on != self.testLegendAttribute(attribute):
@@ -310,9 +341,9 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
         """
         :param int attribute: Legend attribute
         :return: True, when attribute is enabled
-        
+
         .. seealso::
-        
+
             :py:meth:`setLegendAttribute()`
         """
         return self.__data.legendAttributes & attribute
@@ -320,20 +351,20 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def setStyle(self, style):
         """
         Set the curve's drawing style
-        
+
         Valid curve styles:
-        
+
             * `QwtPlotCurve.NoCurve`
             * `QwtPlotCurve.Lines`
             * `QwtPlotCurve.Sticks`
             * `QwtPlotCurve.Steps`
             * `QwtPlotCurve.Dots`
             * `QwtPlotCurve.UserCurve`
-            
+
         :param int style: Curve style
-        
+
         .. seealso::
-        
+
             :py:meth:`style()`
         """
         if style != self.__data.style:
@@ -344,9 +375,9 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def style(self):
         """
         :return: Style of the curve
-        
+
         .. seealso::
-        
+
             :py:meth:`setStyle()`
         """
         return self.__data.style
@@ -356,13 +387,13 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
         Assign a symbol
 
         The curve will take the ownership of the symbol, hence the previously
-        set symbol will be delete by setting a new one. If symbol is None no 
+        set symbol will be delete by setting a new one. If symbol is None no
         symbol will be drawn.
-        
+
         :param qwt.symbol.QwtSymbol symbol: Symbol
-        
+
         .. seealso::
-        
+
             :py:meth:`symbol()`
         """
         if symbol != self.__data.symbol:
@@ -374,9 +405,9 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def symbol(self):
         """
         :return: Current symbol or None, when no symbol has been assigned
-        
+
         .. seealso::
-        
+
             :py:meth:`setSymbol()`
         """
         return self.__data.symbol
@@ -384,27 +415,29 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def setPen(self, *args):
         """
         Build and/or assign a pen, depending on the arguments.
-        
+
         .. py:method:: setPen(color, width, style)
-        
+            :noindex:
+
             Build and assign a pen
-    
+
             In Qt5 the default pen width is 1.0 ( 0.0 in Qt4 ) what makes it
-            non cosmetic (see `QPen.isCosmetic()`). This method signature has 
+            non cosmetic (see `QPen.isCosmetic()`). This method signature has
             been introduced to hide this incompatibility.
-            
+
             :param QColor color: Pen color
             :param float width: Pen width
             :param Qt.PenStyle style: Pen style
-        
+
         .. py:method:: setPen(pen)
-        
+            :noindex:
+
             Assign a pen
-    
+
             :param QPen pen: New pen
-        
+
         .. seealso::
-        
+
             :py:meth:`pen()`, :py:meth:`brush()`
         """
         if len(args) == 3:
@@ -429,9 +462,9 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def pen(self):
         """
         :return: Pen used to draw the lines
-        
+
         .. seealso::
-        
+
             :py:meth:`setPen()`, :py:meth:`brush()`
         """
         return self.__data.pen
@@ -443,17 +476,17 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
         In case of `brush.style() != QBrush.NoBrush`
         and `style() != QwtPlotCurve.Sticks`
         the area between the curve and the baseline will be filled.
-        
+
         In case `not brush.color().isValid()` the area will be filled by
         `pen.color()`. The fill algorithm simply connects the first and the
         last curve point to the baseline. So the curve data has to be sorted
         (ascending or descending).
-        
+
         :param brush: New brush
         :type brush: QBrush or QColor
-        
+
         .. seealso::
-        
+
             :py:meth:`brush()`, :py:meth:`setBaseline()`, :py:meth:`baseline()`
         """
         if isinstance(brush, QColor):
@@ -468,29 +501,29 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def brush(self):
         """
         :return: Brush used to fill the area between lines and the baseline
-        
+
         .. seealso::
-        
-            :py:meth:`setBrush()`, :py:meth:`setBaseline()`, 
+
+            :py:meth:`setBrush()`, :py:meth:`setBaseline()`,
             :py:meth:`baseline()`
         """
         return self.__data.brush
 
     def directPaint(self, from_, to):
         """
-        When observing a measurement while it is running, new points have 
-        to be added to an existing seriesItem. This method can be used to 
+        When observing a measurement while it is running, new points have
+        to be added to an existing seriesItem. This method can be used to
         display them avoiding a complete redraw of the canvas.
 
         Setting `plot().canvas().setAttribute(Qt.WA_PaintOutsidePaintEvent, True)`
-        will result in faster painting, if the paint engine of the canvas 
+        will result in faster painting, if the paint engine of the canvas
         widget supports this feature.
-        
+
         :param int from_: Index of the first point to be painted
         :param int to: Index of the last point to be painted
-        
+
         .. seealso::
-        
+
             :py:meth:`drawSeries()`
         """
         directPainter = QwtPlotDirectPainter(self.plot())
@@ -499,16 +532,16 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def drawSeries(self, painter, xMap, yMap, canvasRect, from_, to):
         """
         Draw an interval of the curve
-        
+
         :param QPainter painter: Painter
         :param qwt.scale_map.QwtScaleMap xMap: Maps x-values into pixel coordinates.
         :param qwt.scale_map.QwtScaleMap yMap: Maps y-values into pixel coordinates.
         :param QRectF canvasRect: Contents rectangle of the canvas
         :param int from_: Index of the first point to be painted
         :param int to: Index of the last point to be painted. If to < 0 the curve will be painted to its last point.
-        
+
         .. seealso::
-        
+
             :py:meth:`drawCurve()`, :py:meth:`drawSymbols()`
         """
         numSamples = self.dataSize()
@@ -533,7 +566,7 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def drawCurve(self, painter, style, xMap, yMap, canvasRect, from_, to):
         """
         Draw the line part (without symbols) of a curve interval.
-        
+
         :param QPainter painter: Painter
         :param int style: curve style, see `QwtPlotCurve.CurveStyle`
         :param qwt.scale_map.QwtScaleMap xMap: Maps x-values into pixel coordinates.
@@ -541,10 +574,10 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
         :param QRectF canvasRect: Contents rectangle of the canvas
         :param int from_: Index of the first point to be painted
         :param int to: Index of the last point to be painted. If to < 0 the curve will be painted to its last point.
-        
+
         .. seealso::
-        
-            :py:meth:`draw()`, :py:meth:`drawDots()`, :py:meth:`drawLines()`, 
+
+            :py:meth:`draw()`, :py:meth:`drawDots()`, :py:meth:`drawLines()`,
             :py:meth:`drawSteps()`, :py:meth:`drawSticks()`
         """
         if style == self.Lines:
@@ -559,17 +592,17 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def drawLines(self, painter, xMap, yMap, canvasRect, from_, to):
         """
         Draw lines
-        
+
         :param QPainter painter: Painter
         :param qwt.scale_map.QwtScaleMap xMap: Maps x-values into pixel coordinates.
         :param qwt.scale_map.QwtScaleMap yMap: Maps y-values into pixel coordinates.
         :param QRectF canvasRect: Contents rectangle of the canvas
         :param int from_: Index of the first point to be painted
         :param int to: Index of the last point to be painted. If to < 0 the curve will be painted to its last point.
-        
+
         .. seealso::
-        
-            :py:meth:`draw()`, :py:meth:`drawDots()`, 
+
+            :py:meth:`draw()`, :py:meth:`drawDots()`,
             :py:meth:`drawSteps()`, :py:meth:`drawSticks()`
         """
         if from_ > to:
@@ -586,17 +619,17 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def drawSticks(self, painter, xMap, yMap, canvasRect, from_, to):
         """
         Draw sticks
-        
+
         :param QPainter painter: Painter
         :param qwt.scale_map.QwtScaleMap xMap: Maps x-values into pixel coordinates.
         :param qwt.scale_map.QwtScaleMap yMap: Maps y-values into pixel coordinates.
         :param QRectF canvasRect: Contents rectangle of the canvas
         :param int from_: Index of the first point to be painted
         :param int to: Index of the last point to be painted. If to < 0 the curve will be painted to its last point.
-        
+
         .. seealso::
-        
-            :py:meth:`draw()`, :py:meth:`drawDots()`, 
+
+            :py:meth:`draw()`, :py:meth:`drawDots()`,
             :py:meth:`drawSteps()`, :py:meth:`drawLines()`
         """
         painter.save()
@@ -618,17 +651,17 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def drawDots(self, painter, xMap, yMap, canvasRect, from_, to):
         """
         Draw dots
-        
+
         :param QPainter painter: Painter
         :param qwt.scale_map.QwtScaleMap xMap: Maps x-values into pixel coordinates.
         :param qwt.scale_map.QwtScaleMap yMap: Maps y-values into pixel coordinates.
         :param QRectF canvasRect: Contents rectangle of the canvas
         :param int from_: Index of the first point to be painted
         :param int to: Index of the last point to be painted. If to < 0 the curve will be painted to its last point.
-        
+
         .. seealso::
-        
-            :py:meth:`draw()`, :py:meth:`drawSticks()`, 
+
+            :py:meth:`draw()`, :py:meth:`drawSticks()`,
             :py:meth:`drawSteps()`, :py:meth:`drawLines()`
         """
         doFill = (
@@ -643,17 +676,17 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def drawSteps(self, painter, xMap, yMap, canvasRect, from_, to):
         """
         Draw steps
-        
+
         :param QPainter painter: Painter
         :param qwt.scale_map.QwtScaleMap xMap: Maps x-values into pixel coordinates.
         :param qwt.scale_map.QwtScaleMap yMap: Maps y-values into pixel coordinates.
         :param QRectF canvasRect: Contents rectangle of the canvas
         :param int from_: Index of the first point to be painted
         :param int to: Index of the last point to be painted. If to < 0 the curve will be painted to its last point.
-        
+
         .. seealso::
-        
-            :py:meth:`draw()`, :py:meth:`drawSticks()`, 
+
+            :py:meth:`draw()`, :py:meth:`drawSticks()`,
             :py:meth:`drawDots()`, :py:meth:`drawLines()`
         """
         polygon = QPolygonF(2 * (to - from_) + 1)
@@ -681,16 +714,16 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def setCurveAttribute(self, attribute, on=True):
         """
         Specify an attribute for drawing the curve
-        
+
         Supported curve attributes:
 
             * `QwtPlotCurve.Inverted`
 
         :param int attribute: Curve attribute
         :param bool on: On/Off
-        
+
         .. seealso::
-        
+
             :py:meth:`testCurveAttribute()`
         """
         if (self.__data.attributes & attribute) == on:
@@ -704,9 +737,9 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def testCurveAttribute(self, attribute):
         """
         :return: True, if attribute is enabled
-        
+
         .. seealso::
-        
+
             :py:meth:`setCurveAttribute()`
         """
         return self.__data.attributes & attribute
@@ -721,10 +754,10 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
         :param qwt.scale_map.QwtScaleMap yMap: Maps y-values into pixel coordinates.
         :param QRectF canvasRect: Contents rectangle of the canvas
         :param QPolygonF polygon: Polygon - will be modified !
-        
+
         .. seealso::
-        
-            :py:meth:`setBrush()`, :py:meth:`setBaseline()`, 
+
+            :py:meth:`setBrush()`, :py:meth:`setBaseline()`,
             :py:meth:`setStyle()`
         """
         if self.__data.brush.style() == Qt.NoBrush:
@@ -743,7 +776,7 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
 
     def closePolyline(self, painter, xMap, yMap, polygon):
         """
-        Complete a polygon to be a closed polygon including the 
+        Complete a polygon to be a closed polygon including the
         area between the original polygon and the baseline.
 
         :param QPainter painter: Painter
@@ -770,7 +803,7 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def drawSymbols(self, painter, symbol, xMap, yMap, canvasRect, from_, to):
         """
         Draw symbols
-        
+
         :param QPainter painter: Painter
         :param qwt.symbol.QwtSymbol symbol: Curve symbol
         :param qwt.scale_map.QwtScaleMap xMap: Maps x-values into pixel coordinates.
@@ -778,10 +811,10 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
         :param QRectF canvasRect: Contents rectangle of the canvas
         :param int from_: Index of the first point to be painted
         :param int to: Index of the last point to be painted. If to < 0 the curve will be painted to its last point.
-        
+
         .. seealso::
-        
-            :py:meth:`setSymbol()`, :py:meth:`drawSeries()`, 
+
+            :py:meth:`setSymbol()`, :py:meth:`drawSeries()`,
             :py:meth:`drawCurve()`
         """
         chunkSize = 500
@@ -797,19 +830,19 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
 
         The baseline is needed for filling the curve with a brush or
         the Sticks drawing style.
-        
+
         The interpretation of the baseline depends on the `orientation()`.
         With `Qt.Horizontal`, the baseline is interpreted as a horizontal line
         at y = baseline(), with `Qt.Vertical`, it is interpreted as a vertical
         line at x = baseline().
-        
+
         The default value is 0.0.
-        
+
         :param float value: Value of the baseline
-        
+
         .. seealso::
-        
-            :py:meth:`baseline()`, :py:meth:`setBrush()`, 
+
+            :py:meth:`baseline()`, :py:meth:`setBrush()`,
             :py:meth:`setStyle()`
         """
         if self.__data.baseline != value:
@@ -819,9 +852,9 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def baseline(self):
         """
         :return: Value of the baseline
-        
+
         .. seealso::
-        
+
             :py:meth:`setBaseline()`
         """
         return self.__data.baseline
@@ -829,16 +862,16 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def closestPoint(self, pos):
         """
         Find the closest curve point for a specific position
-        
+
         :param QPoint pos: Position, where to look for the closest curve point
         :return: tuple `(index, dist)`
-        
-        `dist` is the distance between the position and the closest curve 
-        point. `index` is the index of the closest curve point, or -1 if 
+
+        `dist` is the distance between the position and the closest curve
+        point. `index` is the index of the closest curve point, or -1 if
         none can be found ( f.e when the curve has no points ).
-        
+
         .. note::
-        
+
             `closestPoint()` implements a dumb algorithm, that iterates
             over all points
         """
@@ -866,9 +899,9 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
         :param int index: Index of the legend entry (ignored as there is only one)
         :param QSizeF size: Icon size
         :return: Icon representing the curve on the legend
-        
+
         .. seealso::
-        
+
             :py:meth:`qwt.plot.QwtPlotItem.setLegendIconSize()`,
             :py:meth:`qwt.plot.QwtPlotItem.legendData()`
         """
@@ -912,28 +945,28 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def setData(self, *args, **kwargs):
         """
         Initialize data with a series data object or an array of points.
-        
+
         .. py:method:: setData(data):
-        
+
             :param data: Series data (e.g. `QwtPointArrayData` instance)
             :type data: .plot_series.QwtSeriesData
 
         .. py:method:: setData(xData, yData, [size=None], [finite=True]):
 
             Initialize data with `x` and `y` arrays.
-            
+
             This signature was removed in Qwt6 and is temporarily maintained here to ensure compatibility with Qwt5.
-    
+
             Same as `setSamples(x, y, [size=None], [finite=True])`
-        
+
             :param x: List/array of x values
             :param y: List/array of y values
             :param size: size of xData and yData
             :type size: int or None
             :param bool finite: if True, keep only finite array elements (remove all infinity and not a number values), otherwise do not filter array elements
-        
+
         .. seealso::
-        
+
             :py:meth:`setSamples()`
         """
         if len(args) == 1 and not kwargs:
@@ -949,31 +982,31 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
     def setSamples(self, *args, **kwargs):
         """
         Initialize data with an array of points.
-        
+
         .. py:method:: setSamples(data):
-        
+
             :param data: Series data (e.g. `QwtPointArrayData` instance)
             :type data: .plot_series.QwtSeriesData
-        
-        
+
+
         .. py:method:: setSamples(samples):
-        
+
             Same as `setData(QwtPointArrayData(samples))`
-        
+
             :param samples: List/array of points
-        
+
         .. py:method:: setSamples(xData, yData, [size=None], [finite=True]):
 
             Same as `setData(QwtPointArrayData(xData, yData, [size=None]))`
-        
+
             :param xData: List/array of x values
             :param yData: List/array of y values
             :param size: size of xData and yData
             :type size: int or None
             :param bool finite: if True, keep only finite array elements (remove all infinity and not a number values), otherwise do not filter array elements
-        
+
         .. seealso::
-        
+
             :py:class:`.plot_series.QwtPointArrayData`
         """
         if len(args) == 1 and not kwargs:
@@ -1009,4 +1042,3 @@ class QwtPlotCurve(QwtPlotSeriesItem, QwtSeriesStore):
                 "%s().setSamples() takes 1, 2 or 3 argument(s) "
                 "(%s given)" % (self.__class__.__name__, len(args))
             )
-
